@@ -40,12 +40,13 @@ GtkTreeModelFilter *filter = NULL;
 gboolean more = FALSE, first = TRUE;
 
 
-void dialog_set_labels_selectable(GtkWidget *dialog) {
-	void _set_label_selectable(gpointer data, gpointer user_data) {
-		GtkWidget *widget = GTK_WIDGET(data);
-		if (GTK_IS_LABEL(widget)) gtk_label_set_selectable(GTK_LABEL(widget), TRUE);
-	}
+void _set_label_selectable(gpointer data, gpointer user_data) {
+	GtkWidget *widget = GTK_WIDGET(data);
+	if (GTK_IS_LABEL(widget)) gtk_label_set_selectable(GTK_LABEL(widget), TRUE);
+}
 
+
+void dialog_set_labels_selectable(GtkWidget *dialog) {
 	GtkWidget *area = gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG(dialog));
 	GtkContainer *box = (GtkContainer *) area;
 	GList *children = gtk_container_get_children(box);
@@ -729,7 +730,17 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 	GtkWidget *error;
 	gchar *stmp;
 
-	grsync_dir = g_strconcat(g_get_home_dir(), "/.grsync", NULL);
+	grsync_dir = g_strconcat(g_get_user_config_dir(), "/grsync", NULL);
+	if (!g_file_test(grsync_dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
+		g_free(grsync_dir);
+		grsync_dir = g_strconcat(g_get_home_dir(), "/.grsync", NULL);
+
+		if (!g_file_test(grsync_dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
+			g_free(grsync_dir);
+			grsync_dir = g_strconcat(g_get_user_config_dir(), "/grsync", NULL);
+		}
+	}
+
 	if (!load_groups(argv_session)) {
 		error = gtk_message_dialog_new(window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL,
 			_("The session you specified on the command line doesn't exists"));
@@ -1113,7 +1124,7 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 
 	view = (GtkTextView*)gtk_builder_get_object(builder, "textview_output");
 	PangoFontDescription *font_desc = pango_font_description_from_string("monospace 10");
-	gtk_widget_modify_font((GtkWidget*) view, font_desc);
+	gtk_widget_override_font((GtkWidget*) view, font_desc);
 	pango_font_description_free(font_desc);
 
 	buffer = gtk_text_view_get_buffer(view);
